#!/usr/bin/python

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
sys.path.insert(0, ".")
from src import buildinfo
from src._version import version_info
from textwrap import wrap

if version_info['revision_id'] != buildinfo.REVISION_ID:
    print "\n", "\n".join(wrap("Set the revision-id in configure.ac, run autoconf and ./configure before re-running the test.")), "\n"
    sys.exit(1)
sys.exit(0)
